@@ -11,29 +11,34 @@
 
 import argparse
 
-import pvleopard
-import soundfile
+from pvleopard import *
+from tabulate import tabulate
 
 
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('--access_key', required=True)
-    parser.add_argument('--library_path', default=None)
     parser.add_argument('--model_path', default=None)
-
+    parser.add_argument('--library_path', default=None)
+    parser.add_argument('--disable_automatic_punctuation', action='store_true')
+    parser.add_argument('--verbose', action='store_true')
     parser.add_argument('--audio_paths', nargs='+', required=True)
-
     args = parser.parse_args()
 
-    leopard = pvleopard.create(access_key=args.access_key, library_path=args.library_path, model_path=args.model_path)
+    o = create(
+        access_key=args.access_key,
+        model_path=args.model_path,
+        library_path=args.library_path,
+        enable_automatic_punctuation=not args.disable_automatic_punctuation)
 
-    for audio_path in args.audio_paths:
-        audio, sample_rate = soundfile.read(audio_path, dtype='int16')
-        if sample_rate != leopard.sample_rate:
-            raise ValueError('Leopard can only process audio data with sample rate of %d' % leopard.sample_rate)
-
-        transcript = leopard.process(audio)
-        print(transcript)
+    try:
+        for audio_path in args.audio_paths:
+            transcript, words = o.process_file(audio_path)
+            print(transcript)
+            if args.verbose:
+                print(tabulate(words, headers=['word', 'start_sec', 'end_sec', 'confidence'], floatfmt='.2f'))
+    except LeopardActivationLimitError:
+        print("AccessKey '%s' has reached it's processing limit." % args.access_key)
 
 
 if __name__ == '__main__':
